##  Resyncing IT Components
To update IT components with the latest information from the reference catalog, you can manually resync them by clicking Resync IT Components. This updates all IT components linked to the catalog with the fields and relations defined in your synchronization configuration. A manual resync may be necessary in the following situations:
  * As an admin user, you've changed your synchronization configuration settings to include more attributes. Resyncing lets you import selected attributes to fact sheets, regardless of whether these attributes were filled out manually.
  * Users accidentally changed some fields related to the catalog on fact sheets, and you want to revert the changes to the standard setup.


When resyncing IT components, proceed with caution, as this action cannot be undone. Before running a manual resync, you can create a snapshot of your workspace in the Export section of the admin area. For more details, see [Export](https://help.sap.com/docs/leanix/ea/export?locale=en-US&state=PRODUCTION&version=CLOUD "Export your workspace data and view the export history.").
